@@ -72,7 +72,7 @@ impl Application for RusticApp {
         &mut self,
         command: &Self::Cmd,
     ) -> Result<Vec<Box<dyn Component<Self>>>, FrameworkError> {
-        // we only ue the terminal component
+        // we only use the terminal component
         let terminal = Terminal::new(self.term_colors(command));
 
         Ok(vec![Box::new(terminal)])
@@ -99,7 +99,7 @@ impl Application for RusticApp {
         self.state.components_mut().after_config(&config)?;
 
         // set all given environment variables
-        for (env, value) in config.global.env.iter() {
+        for (env, value) in &config.global.env {
             env::set_var(env, value);
         }
 
