@@ -16,6 +16,8 @@ pub(crate) mod key;
 pub(crate) mod list;
 pub(crate) mod ls;
 pub(crate) mod merge;
+#[cfg(feature = "mount")]
+pub(crate) mod mount;
 pub(crate) mod prune;
 pub(crate) mod repair;
 pub(crate) mod repoinfo;
@@ -33,7 +35,10 @@ use std::fmt::Debug;
 use std::fs::File;
 use std::path::PathBuf;
 use std::str::FromStr;
+use std::sync::mpsc::channel;
 
+#[cfg(feature = "mount")]
+use crate::commands::mount::MountCmd;
 #[cfg(feature = "webdav")]
 use crate::commands::webdav::WebDavCmd;
 use crate::{
@@ -60,7 +65,7 @@ use clap::builder::{
 };
 use convert_case::{Case, Casing};
 use human_panic::setup_panic;
-use log::{log, Level};
+use log::{info, log, Level};
 use simplelog::{CombinedLogger, LevelFilter, TermLogger, TerminalMode, WriteLogger};
 
 use self::find::FindCmd;
@@ -111,6 +116,10 @@ enum RusticCmd {
     /// List repository files by file type
     List(Box<ListCmd>),
 
+    #[cfg(feature = "mount")]
+    /// Mount a repository as read-only filesystem
+    Mount(Box<MountCmd>),
+
     /// List file contents of a snapshot
     Ls(Box<LsCmd>),
 
@@ -171,6 +180,20 @@ impl Runnable for EntryPoint {
         // Set up panic hook for better error messages and logs
         setup_panic!();
 
+        // Set up Ctrl-C handler
+        let (tx, rx) = channel();
+
+        ctrlc::set_handler(move || tx.send(()).expect("Could not send signal on channel."))
+            .expect("Error setting Ctrl-C handler");
+
+        _ = std::thread::spawn(move || {
+            // Wait for Ctrl-C
+            rx.recv().expect("Could not receive from channel.");
+            info!("Ctrl-C received, shutting down...");
+            RUSTIC_APP.shutdown(Shutdown::Graceful)
+        });
+
+        // Run the subcommand
         self.commands.run();
         RUSTIC_APP.shutdown(Shutdown::Graceful)
     }
@@ -278,6 +301,8 @@ impl Configurable<RusticConfig> for EntryPoint {
             RusticCmd::Copy(cmd) => cmd.override_config(config),
             #[cfg(feature = "webdav")]
             RusticCmd::Webdav(cmd) => cmd.override_config(config),
+            #[cfg(feature = "mount")]
+            RusticCmd::Mount(cmd) => cmd.override_config(config),
 
             // subcommands that don't need special overrides use a catch all
             _ => Ok(config),
