@@ -2,7 +2,7 @@
 
 use std::path::Path;
 
-use crate::{commands::open_repository_indexed, status_err, Application, RUSTIC_APP};
+use crate::{repository::CliIndexedRepo, status_err, Application, RUSTIC_APP};
 
 use abscissa_core::{Command, Runnable, Shutdown};
 use anyhow::Result;
@@ -58,14 +58,18 @@ pub(crate) struct LsCmd {
 
 impl Runnable for LsCmd {
     fn run(&self) {
-        if let Err(err) = self.inner_run() {
+        if let Err(err) = RUSTIC_APP
+            .config()
+            .repository
+            .run_indexed(|repo| self.inner_run(repo))
+        {
             status_err!("{}", err);
             RUSTIC_APP.shutdown(Shutdown::Crash);
         };
     }
 }
 
-/// Sumary of a ls command
+/// Summary of a ls command
 ///
 /// This struct is used to print a summary of the ls command.
 #[derive(Default)]
@@ -112,8 +116,7 @@ impl NodeLs for Node {
             },
             self.meta
                 .mode
-                .map(parse_permissions)
-                .unwrap_or_else(|| "?????????".to_string())
+                .map_or_else(|| "?????????".to_string(), parse_permissions)
         )
     }
     fn link_str(&self) -> String {
@@ -126,9 +129,8 @@ impl NodeLs for Node {
 }
 
 impl LsCmd {
-    fn inner_run(&self) -> Result<()> {
+    fn inner_run(&self, repo: CliIndexedRepo) -> Result<()> {
         let config = RUSTIC_APP.config();
-        let repo = open_repository_indexed(&config.repository)?;
 
         let node =
             repo.node_from_snapshot_path(&self.snap, |sn| config.snapshot_filter.matches(sn))?;
@@ -198,10 +200,10 @@ pub fn print_node(node: &Node, path: &Path, numeric_uid_gid: bool) {
         }
         .unwrap_or_else(|| "?".to_string()),
         node.meta.size,
-        node.meta
-            .mtime
-            .map(|t| t.format("%_d %b %Y %H:%M").to_string())
-            .unwrap_or_else(|| "?".to_string()),
+        node.meta.mtime.map_or_else(
+            || "?".to_string(),
+            |t| t.format("%_d %b %Y %H:%M").to_string()
+        ),
         node.link_str(),
     );
 }
