@@ -1,10 +1,13 @@
-use std::{iter::once, str::FromStr};
+use std::{collections::BTreeSet, iter::once, mem, str::FromStr};
 
 use anyhow::Result;
 use chrono::Local;
 use crossterm::event::{Event, KeyCode, KeyEventKind, KeyModifiers};
 use itertools::Itertools;
-use ratatui::{prelude::*, widgets::*};
+use ratatui::{
+    prelude::*,
+    widgets::{Block, Borders, Paragraph},
+};
 use rustic_core::{
     repofile::{DeleteOption, SnapshotFile},
     IndexedFull, ProgressBars, Repository, SnapshotGroup, SnapshotGroupCriterion, StringList,
@@ -74,7 +77,7 @@ enum SnapshotNode {
 const INFO_TEXT: &str =
     "(Esc) quit | (F5) reload snapshots | (Enter) show contents | (v) toggle view | (i) show snapshot | (?) show all commands";
 
-const HELP_TEXT: &str = r#"General Commands:
+const HELP_TEXT: &str = r"General Commands:
   q, Esc : exit
       F5 : re-read all snapshots from repository
    Enter : show snapshot contents
@@ -105,7 +108,7 @@ const HELP_TEXT: &str = r#"General Commands:
        r : remove tag(s) for snapshot(s)
        p : set delete protection for snapshot(s)
   Ctrl-p : remove delete protection for snapshot(s)
-"#;
+";
 
 pub(crate) struct Snapshots<'a, P, S> {
     current_screen: CurrentScreen<'a, P, S>,
@@ -362,11 +365,11 @@ impl<'a, P: ProgressBars, S: IndexedFull> Snapshots<'a, P, S> {
                 let paths = group
                     .paths
                     .as_ref()
-                    .map_or_else(String::default, |p| p.formatln());
+                    .map_or_else(String::default, StringList::formatln);
                 let tags = group
                     .tags
                     .as_ref()
-                    .map_or_else(String::default, |t| t.formatln());
+                    .map_or_else(String::default, StringList::formatln);
                 [
                     mark.to_string(),
                     format!("{collapse}{modified}{del}group"),
@@ -437,7 +440,7 @@ impl<'a, P: ProgressBars, S: IndexedFull> Snapshots<'a, P, S> {
     }
 
     pub fn clear_marks(&mut self) {
-        for status in self.snaps_status.iter_mut() {
+        for status in &mut self.snaps_status {
             status.marked = false;
         }
         self.update_table();
@@ -650,7 +653,7 @@ impl<'a, P: ProgressBars, S: IndexedFull> Snapshots<'a, P, S> {
     }
 
     pub fn clear_to_forget(&mut self) {
-        for status in self.snaps_status.iter_mut() {
+        for status in &mut self.snaps_status {
             status.to_forget = false;
         }
         self.update_table();
@@ -697,13 +700,17 @@ impl<'a, P: ProgressBars, S: IndexedFull> Snapshots<'a, P, S> {
         let delete_ids: Vec<_> = old_snap_ids.chain(snap_ids_to_forget).collect();
         self.repo.save_snapshots(save_snaps)?;
         self.repo.delete_snapshots(&delete_ids)?;
+        // remove snapshots-to-reread
+        let ids: BTreeSet<_> = delete_ids.into_iter().collect();
+        self.snapshots.retain(|snap| !ids.contains(&snap.id));
         // re-read snapshots
         self.reread()
     }
 
     // re-read all snapshots
     pub fn reread(&mut self) -> Result<()> {
-        self.snapshots = self.repo.get_all_snapshots()?;
+        let snapshots = mem::take(&mut self.snapshots);
+        self.snapshots = self.repo.update_all_snapshots(snapshots)?;
         self.snapshots
             .sort_unstable_by(|sn1, sn2| sn1.cmp_group(self.group_by, sn2).then(sn1.cmp(sn2)));
         self.snaps_status = vec![SnapStatus::default(); self.snapshots.len()];
@@ -714,7 +721,7 @@ impl<'a, P: ProgressBars, S: IndexedFull> Snapshots<'a, P, S> {
     }
 
     pub fn input(&mut self, event: Event) -> Result<bool> {
-        use KeyCode::*;
+        use KeyCode::{Char, Enter, Esc, Left, Right, F};
         match &mut self.current_screen {
             CurrentScreen::Snapshots => {
                 match event {
@@ -842,10 +849,7 @@ impl<'a, P: ProgressBars, S: IndexedFull> Snapshots<'a, P, S> {
             }
             CurrentScreen::SnapshotDetails(_) | CurrentScreen::ShowHelp(_) => match event {
                 Event::Key(key) if key.kind == KeyEventKind::Press => {
-                    if matches!(
-                        key.code,
-                        Char('q') | Esc | Enter | Char(' ') | Char('i') | Char('?')
-                    ) {
+                    if matches!(key.code, Char('q' | ' ' | 'i' | '?') | Esc | Enter) {
                         self.current_screen = CurrentScreen::Snapshots;
                     }
                 }
