@@ -3,9 +3,9 @@
 // ignore markdown clippy lints as we use doc-comments to generate clap help texts
 #![allow(clippy::doc_markdown)]
 
-use std::{net::ToSocketAddrs, str::FromStr};
+use std::net::ToSocketAddrs;
 
-use crate::{commands::open_repository_indexed, status_err, Application, RusticConfig, RUSTIC_APP};
+use crate::{repository::CliIndexedRepo, status_err, Application, RusticConfig, RUSTIC_APP};
 use abscissa_core::{config::Override, Command, FrameworkError, Runnable, Shutdown};
 use anyhow::{anyhow, Result};
 use conflate::Merge;
@@ -13,6 +13,9 @@ use dav_server::{warp::dav_handler, DavHandler};
 use serde::{Deserialize, Serialize};
 
 use rustic_core::vfs::{FilePolicy, IdenticalSnapshot, Latest, Vfs};
+use webdavfs::WebDavFS;
+
+mod webdavfs;
 
 #[derive(Clone, Command, Default, Debug, clap::Parser, Serialize, Deserialize, Merge)]
 #[serde(default, rename_all = "kebab-case", deny_unknown_fields)]
@@ -63,7 +66,11 @@ impl Override<RusticConfig> for WebDavCmd {
 
 impl Runnable for WebDavCmd {
     fn run(&self) {
-        if let Err(err) = self.inner_run() {
+        if let Err(err) = RUSTIC_APP
+            .config()
+            .repository
+            .run_indexed(|repo| self.inner_run(repo))
+        {
             status_err!("{}", err);
             RUSTIC_APP.shutdown(Shutdown::Crash);
         };
@@ -74,9 +81,8 @@ impl WebDavCmd {
     /// be careful about self VS RUSTIC_APP.config() usage
     /// only the RUSTIC_APP.config() involves the TOML and ENV merged configurations
     /// see https://github.com/rustic-rs/rustic/issues/1242
-    fn inner_run(&self) -> Result<()> {
+    fn inner_run(&self, repo: CliIndexedRepo) -> Result<()> {
         let config = RUSTIC_APP.config();
-        let repo = open_repository_indexed(&config.repository)?;
 
         let path_template = config
             .webdav
@@ -121,11 +127,12 @@ impl WebDavCmd {
                     Ok(FilePolicy::Read)
                 }
             },
-            |s| FilePolicy::from_str(s),
+            |s| s.parse(),
         )?;
 
+        let webdavfs = WebDavFS::new(repo, vfs, file_access);
         let dav_server = DavHandler::builder()
-            .filesystem(vfs.into_webdav_fs(repo, file_access))
+            .filesystem(Box::new(webdavfs))
             .build_handler();
 
         tokio::runtime::Builder::new_current_thread()
