@@ -4,28 +4,36 @@
 //! application's configuration file and/or command-line options
 //! for specifying it.
 
+pub(crate) mod hooks;
 pub(crate) mod progress_options;
 
-use std::{collections::HashMap, path::PathBuf};
+use std::{
+    collections::BTreeMap,
+    fmt::{self, Display, Formatter},
+    path::PathBuf,
+};
 
-use abscissa_core::config::Config;
-use abscissa_core::path::AbsPathBuf;
-use abscissa_core::FrameworkError;
+use abscissa_core::{config::Config, path::AbsPathBuf, FrameworkError};
+use anyhow::Result;
 use clap::{Parser, ValueHint};
 use conflate::Merge;
 use directories::ProjectDirs;
 use itertools::Itertools;
 use log::Level;
-use rustic_backend::BackendOptions;
-use rustic_core::RepositoryOptions;
 use serde::{Deserialize, Serialize};
+#[cfg(not(all(feature = "mount", feature = "webdav")))]
+use toml::Value;
 
+#[cfg(feature = "mount")]
+use crate::commands::mount::MountCmd;
 #[cfg(feature = "webdav")]
 use crate::commands::webdav::WebDavCmd;
+
 use crate::{
     commands::{backup::BackupCmd, copy::CopyCmd, forget::ForgetOptions},
-    config::progress_options::ProgressOptions,
+    config::{hooks::Hooks, progress_options::ProgressOptions},
     filtering::SnapshotFilter,
+    repository::AllRepositoryOptions,
 };
 
 /// Rustic Configuration
@@ -61,24 +69,30 @@ pub struct RusticConfig {
     #[clap(skip)]
     pub forget: ForgetOptions,
 
-    #[cfg(feature = "webdav")]
+    /// mount options
+    #[clap(skip)]
+    #[cfg(feature = "mount")]
+    pub mount: MountCmd,
+    #[cfg(not(feature = "mount"))]
+    #[merge(skip)]
+    pub mount: Option<Value>,
+
     /// webdav options
     #[clap(skip)]
+    #[cfg(feature = "webdav")]
     pub webdav: WebDavCmd,
+    #[cfg(not(feature = "webdav"))]
+    #[merge(skip)]
+    pub webdav: Option<Value>,
 }
 
-#[derive(Clone, Default, Debug, Parser, Serialize, Deserialize, Merge)]
-#[serde(default, rename_all = "kebab-case")]
-pub struct AllRepositoryOptions {
-    /// Backend options
-    #[clap(flatten)]
-    #[serde(flatten)]
-    pub be: BackendOptions,
+impl Display for RusticConfig {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        let config = toml::to_string_pretty(self)
+            .unwrap_or_else(|_| "<Error serializing config>".to_string());
 
-    /// Repository options
-    #[clap(flatten)]
-    #[serde(flatten)]
-    pub repo: RepositoryOptions,
+        write!(f, "{config}",)
+    }
 }
 
 impl RusticConfig {
@@ -144,7 +158,7 @@ pub struct GlobalOptions {
     #[merge(strategy=conflate::bool::overwrite_false)]
     pub dry_run: bool,
 
-    /// Check if index matches pack files and read pack headers if neccessary
+    /// Check if index matches pack files and read pack headers if necessary
     #[clap(long, global = true, env = "RUSTIC_CHECK_INDEX")]
     #[merge(strategy=conflate::bool::overwrite_false)]
     pub check_index: bool,
@@ -168,10 +182,14 @@ pub struct GlobalOptions {
     #[serde(flatten)]
     pub progress_options: ProgressOptions,
 
+    /// Hooks
+    #[clap(skip)]
+    pub hooks: Hooks,
+
     /// List of environment variables to set (only in config file)
     #[clap(skip)]
-    #[merge(strategy = conflate::hashmap::ignore)]
-    pub env: HashMap<String, String>,
+    #[merge(strategy = conflate::btreemap::append_or_ignore)]
+    pub env: BTreeMap<String, String>,
 }
 
 /// Get the paths to the config file
@@ -235,3 +253,47 @@ fn get_global_config_path() -> Option<PathBuf> {
 fn get_global_config_path() -> Option<PathBuf> {
     Some(PathBuf::from("/etc/rustic"))
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use insta::{assert_debug_snapshot, assert_snapshot};
+
+    #[test]
+    fn test_default_config_passes() {
+        let config = RusticConfig::default();
+
+        assert_debug_snapshot!(config);
+    }
+
+    #[test]
+    fn test_default_config_display_passes() {
+        let config = RusticConfig::default();
+
+        assert_snapshot!(config);
+    }
+
+    #[test]
+    fn test_global_env_roundtrip_passes() {
+        let mut config = RusticConfig::default();
+
+        for i in 0..10 {
+            let _ = config
+                .global
+                .env
+                .insert(format!("KEY{}", i), format!("VALUE{}", i));
+        }
+
+        let serialized = toml::to_string(&config).unwrap();
+
+        // Check Serialization
+        assert_snapshot!(serialized);
+
+        let deserialized: RusticConfig = toml::from_str(&serialized).unwrap();
+        // Check Deserialization and Display
+        assert_snapshot!(deserialized);
+
+        // Check Debug
+        assert_debug_snapshot!(deserialized);
+    }
+}
