@@ -51,6 +51,10 @@ Application based on the [Abscissa] framework.
     clippy::trivially_copy_pass_by_ref
 )]
 #![allow(
+    // Popped up in 1.83.0
+    non_local_definitions,
+    // False-positive in WebDavFs
+    elided_named_lifetimes,
     clippy::module_name_repetitions,
     clippy::redundant_pub_crate,
     clippy::missing_const_for_fn
@@ -62,6 +66,7 @@ pub(crate) mod config;
 pub(crate) mod error;
 pub(crate) mod filtering;
 pub(crate) mod helpers;
+pub(crate) mod repository;
 
 // rustic_cli Public API
 
